%
% File test filtro
%

% Create a signal to use in the example

rng default

noise_std = 0;
Fs = 1000;
t = linspace(0,1,Fs);
x = cos(2*pi*100*t) + noise_std*randn(size(t));

% Design the filter and view the magnitude response.

fc = 200; % Filter cut-off frequency
Wn = (2/Fs)*fc;
b = fir1(20,Wn,'low',kaiser(21,3));

[h,f] = freqz(b,1,[],Fs);
figure
plot(f,mag2db(abs(h))) % Frequency diagram of the filter
xlabel('Frequency (Hz)')
ylabel('Magnitude (dB)')
grid

% Apply the filter to the signal and plot 
% the result for the first ten periods of the 100 Hz sinusoid.

y = filter(b,1,x);

figure
plot(t,x,t,y)
xlim([0 0.1])

xlabel('Time (s)')
ylabel('Amplitude')
legend('Original Signal','Filtered Data')

% Design the same filter using designfilt. 
% Set the filter response to 'lowpassfir' and 
% input the specifications as Name,Value pairs. 
% With designfilt, you can specify your filter 
% design in Hz.


Hd = designfilt('lowpassfir','FilterOrder',20,'CutoffFrequency',fc, ...
       'DesignMethod','window','Window',{@kaiser,3},'SampleRate',Fs);

% Filter the data and plot the result

y1 = filter(Hd,x); % Data filtering

fvtool(Hd) % Frequency diagram of the filter

figure
plot(t,x,t,y1)
xlim([0 0.1])

xlabel('Time (s)')
ylabel('Amplitude')
legend('Original Signal','Filtered Data')
